window.onload = init;

function init() {
    new Vue({
        el: "#app",
        data: {
            restaurants: [{
                    nom: 'café de Paris',
                    cuisine: 'Française'
                },
                {
                    nom: 'Sun City Café',
                    cuisine: 'Américaine'
                }
            ],
            nom: '',
            cuisine: '',
            nbRestaurants: 0,
            page: 0,
            nbRestaurantsParPage: 5,
            nomRecherche: ""
        },
        mounted() {
            console.log("AVANT AFFICHAGE");
            this.getRestaurantsFromServer();
        },
        methods: {
            getRestaurantsFromServer() {
                let url = "http://localhost:8080/api/restaurants?page=" +
                    this.page + "&name=" + this.nomRecherche +
                    "&pagesize=" + this.nbRestaurantsParPage;

                console.log("Je vais chercher les restaurants sur : " + url)

                fetch(url)
                    .then((reponseJSON) => {
                        //console.log("reponse json");
                        return reponseJSON.json();
                    })
                    .then((reponseJS) => {
                        // ici on a une réponse en JS
                        this.restaurants = reponseJS.data;
                        this.nbRestaurants = reponseJS.count;
                    })
                    .catch((err) => {
                        console.log("Une erreur est intervenue " + err);
                    })
            },

            // _.debounce vient de lodash et permet de n'appeler getRestaurantsFromServer que lorsqu'on a arrêté de taper
            // pendant 300ms, ça évite d'envoyer une requête au serveur à chaque touche...
            searchRestaurantsFromServer: _.debounce(
                function () {
                    this.getRestaurantsFromServer();
                }, 300),


            supprimerRestaurant(index) {
                this.restaurants.splice(index, 1);
            },
            ajouterRestaurant(event) {
                // On récupère le formulaire
                // on l'envoie en multipart sur le serveur
                // Pour éviter que la page ne se ré-affiche
                event.preventDefault();

                // Récupération du formulaire. Pas besoin de document.querySelector
                // ou document.getElementById puisque c'est le formulaire qui a généré
                // l'événement
                let form = event.target;

                // Récupération des valeurs des champs du formulaire
                // en prévision d'un envoi multipart en ajax/fetch
                let donneesFormulaire = new FormData(form);

                let url = "http://localhost:8080/api/restaurants";

                fetch(url, {
                        method: "POST",
                        body: donneesFormulaire
                    })
                    .then((responseJSON) => {
                        responseJSON.json()
                            .then((res) => { // arrow function préserve le this
                                // Maintenant res est un vrai objet JavaScript
                                console.log("Restaurant inséré");
                                this.getRestaurantsFromServer();

                                // remettre le formulaire à zéro
                                this.nom = "";
                                this.cuisine = "";
                            });
                    })
                    .catch(function (err) {
                        console.log(err);
                    });
            },
            getColor(index) {
                return (index == 4) ? 'pink' : 'orange';
            },
            pagePrecedente() {
                if (this.page > 0) {
                    this.page--;
                    this.getRestaurantsFromServer();
                }
            },
            pageSuivante() {
                this.page++;
                this.getRestaurantsFromServer();
            },
            changePageSize() {
                this.getRestaurantsFromServer();
            }
        }
    });
}